#[repr(usize)]pub enum Event {
Show 49 variants
ClientCreated = 0,
ClientDropped = 1,
ClientClosed = 2,
AssociateName = 3,
CreatedDM = 4,
CreatedGroup = 5,
AddedMembers = 6,
ReceivedWelcome = 7,
MLSReceivedStagedCommit = 8,
MLSProcessedStagedCommit = 9,
MLSReceivedApplicationMessage = 10,
StreamOpened = 11,
StreamClosed = 12,
GroupSyncStart = 13,
GroupSyncAttempt = 14,
GroupSyncFinished = 15,
GroupSyncGroupInactive = 16,
GroupSyncIntentRetry = 17,
GroupSyncIntentErrored = 18,
GroupSyncPublishFailed = 19,
GroupSyncApplicationMessagePublishSuccess = 20,
GroupSyncCommitPublishSuccess = 21,
GroupSyncStagedCommitPresent = 22,
GroupCursorUpdate = 23,
UpdatedGroupMembership = 24,
DeviceSyncInitializing = 25,
DeviceSyncInitializingFinished = 26,
DeviceSyncNoPrimarySyncGroup = 27,
DeviceSyncCreatedPrimarySyncGroup = 28,
DeviceSyncSentSyncRequest = 29,
DeviceSyncProcessingMessages = 30,
DeviceSyncMessageProcessingError = 31,
DeviceSyncArchiveProcessingStart = 32,
DeviceSyncV1Archive = 33,
DeviceSyncArchiveNotRequested = 34,
DeviceSyncArchiveDownloading = 35,
DeviceSyncPayloadDownloadFailure = 36,
DeviceSyncArchiveImportStart = 37,
DeviceSyncArchiveImportSuccess = 38,
DeviceSyncArchiveImportFailure = 39,
DeviceSyncRequestAlreadyAcknowledged = 40,
DeviceSyncRequestAcknowledged = 41,
DeviceSyncResponseTaskScheduled = 42,
DeviceSyncArchiveUploadStart = 43,
DeviceSyncArchiveUploadFailure = 44,
DeviceSyncArchiveUploadComplete = 45,
DeviceSyncNoServerUrl = 46,
EnableProposalsStart = 47,
EnableProposalsCompleted = 48,
}Variants
ClientCreated = 0
Client created.
ClientDropped = 1
Client dropped.
ClientClosed = 2
Client cleanly closed via Client::close.
AssociateName = 3
Associating name with installation.
CreatedDM = 4
DM created.
CreatedGroup = 5
Group created.
AddedMembers = 6
Added members to group.
ReceivedWelcome = 7
Received new group from welcome.
MLSReceivedStagedCommit = 8
Received staged commit. Merging and clearing any pending commits.
MLSProcessedStagedCommit = 9
Processed staged commit.
MLSReceivedApplicationMessage = 10
Received application message.
StreamOpened = 11
Stream started.
StreamClosed = 12
Stream closed.
GroupSyncStart = 13
Begin syncing group.
GroupSyncAttempt = 14
Syncing group.
GroupSyncFinished = 15
Group sync complete.
GroupSyncGroupInactive = 16
Attempted to sync on an inactive group.
GroupSyncIntentRetry = 17
Intent failed to sync and will be retried.
GroupSyncIntentErrored = 18
Intent was found to be in error after attempting to sync.
The summary is logged once by GroupSyncFinished; this only marks
which intent errored.
GroupSyncPublishFailed = 19
Attempt to publish intent failed.
GroupSyncApplicationMessagePublishSuccess = 20
Application message published successfully.
GroupSyncCommitPublishSuccess = 21
Commit published successfully.
GroupSyncStagedCommitPresent = 22
Commit sent. Staged commit is present. Stopping further publishes for this round.
GroupCursorUpdate = 23
Updating group cursor.
UpdatedGroupMembership = 24
Updated group membership.
DeviceSyncInitializing = 25
Device Sync worker initializing.
DeviceSyncInitializingFinished = 26
Device sync initialized.
DeviceSyncNoPrimarySyncGroup = 27
No primary sync group found.
DeviceSyncCreatedPrimarySyncGroup = 28
Created primary sync group.
DeviceSyncSentSyncRequest = 29
Sent a sync request.
DeviceSyncProcessingMessages = 30
Processing new sync message.
DeviceSyncMessageProcessingError = 31
Failed to process device sync message.
DeviceSyncArchiveProcessingStart = 32
Processing sync archive.
DeviceSyncV1Archive = 33
Received a V1 sync payload. V1 is no longer supported. Ignoring.
DeviceSyncArchiveNotRequested = 34
Received a sync archive message, but it was not requested by this instalaltion. Skipping.
DeviceSyncArchiveDownloading = 35
Downloading sync archive.
DeviceSyncPayloadDownloadFailure = 36
Sync archive download failure.
DeviceSyncArchiveImportStart = 37
Beginning archive import.
DeviceSyncArchiveImportSuccess = 38
Finished sync archive import.
DeviceSyncArchiveImportFailure = 39
Archive import failed.
DeviceSyncRequestAlreadyAcknowledged = 40
Attempted to acknowledge a sync request, but it was already acknowledged by another installation.
DeviceSyncRequestAcknowledged = 41
Acknowledged sync request.
DeviceSyncResponseTaskScheduled = 42
Scheduled task to respond to sync request.
DeviceSyncArchiveUploadStart = 43
Sending sync archive.
DeviceSyncArchiveUploadFailure = 44
Failed to send sync archive.
DeviceSyncArchiveUploadComplete = 45
Archive upload complete.
DeviceSyncNoServerUrl = 46
Cannot send sync archive. No server_url present.
EnableProposalsStart = 47
enable_proposals started — pre-flight passed, about to publish
the legacy-GMM bump (step A) and/or bootstrap commit (step B).
EnableProposalsCompleted = 48
enable_proposals completed. already_migrated = true means
the call was a no-op fast-path; false means a bootstrap
commit was actually published.
Implementations
Sourceimpl Event
impl Event
Sourcepub const METADATA: [EventMetadata; 49]
pub const METADATA: [EventMetadata; 49]
Metadata for all variants of this enum, indexed by variant discriminant.
Sourcepub const fn metadata(&self) -> &'static EventMetadata
pub const fn metadata(&self) -> &'static EventMetadata
Returns the metadata for this event variant.